@@ -10,9 +10,40 @@
 #[cfg(any(test, feature = "test-utils"))]
 pub mod test_utils;
 
-use rand::distributions::{Alphanumeric, Distribution, Standard};
-use rand::rngs::OsRng;
-use rand::{self, Rng};
+use crate::types::{Encryption, PublicKey, Result};
+use crate::url::Scope;
+use bytes::Bytes;
+use rand::{self, distributions::Alphanumeric, rngs::OsRng, Rng};
+
+struct DummyEncryption {
+    public_key: PublicKey,
+}
+
+impl DummyEncryption {
+    pub(crate) fn new(public_key: PublicKey) -> Self {
+        Self { public_key }
+    }
+}
+
+impl Encryption for DummyEncryption {
+    fn public_key(&self) -> &PublicKey {
+        &self.public_key
+    }
+    fn encrypt(&self, data: Bytes) -> Result<Bytes> {
+        Ok(data)
+    }
+    fn decrypt(&self, encrypted_data: Bytes) -> Result<Bytes> {
+        Ok(encrypted_data)
+    }
+}
+
+///
+pub fn encryption(scope: Scope, public_key: PublicKey) -> Option<impl Encryption> {
+    match scope {
+        Scope::Public => None,
+        Scope::Private => Some(DummyEncryption::new(public_key)),
+    }
+}
 
 /// Generates a `String` from `length` random UTF-8 `char`s.  Note that the NULL character will be
 /// excluded to allow conversion to a `CString` if required, and that the actual `len()` of the
@@ -36,18 +67,6 @@ pub fn generate_readable_string(length: usize) -> String {
         .collect()
 }
 
-/// Generates a random vector using provided `length`.
-pub fn generate_random_vector<T>(length: usize) -> Vec<T>
-where
-    Standard: Distribution<T>,
-{
-    let mut rng = OsRng;
-    ::std::iter::repeat(())
-        .map(|()| rng.gen::<T>())
-        .take(length)
-        .collect()
-}
-
 /// Convert binary data to a diplay-able format
 #[inline]
 pub fn bin_data_format(data: &[u8]) -> String {
@@ -71,6 +90,8 @@ pub fn bin_data_format(data: &[u8]) -> String {
 
 #[cfg(test)]
 mod tests {
+    use crate::types::utils::random_bytes;
+
     use super::*;
 
     const SIZE: usize = 10;
@@ -91,12 +112,12 @@ mod tests {
         assert_eq!(str2.chars().count(), SIZE);
     }
 
-    // Test `generate_random_vector` and that the results are not repeated.
+    // Test `random_bytes` and that the results are not repeated.
     #[test]
     fn random_vector() {
-        let vec0 = generate_random_vector::<u8>(SIZE);
-        let vec1 = generate_random_vector::<u8>(SIZE);
-        let vec2 = generate_random_vector::<u8>(SIZE);
+        let vec0 = random_bytes(SIZE);
+        let vec1 = random_bytes(SIZE);
+        let vec2 = random_bytes(SIZE);
 
         assert_ne!(vec0, vec1);
         assert_ne!(vec0, vec2);
